View source: R/zap_everything.R
| zap_everything | R Documentation |
haven::read_sav can be used to
read.sav and .zsav files into R. It preserves SPSS-related
information such as labels and attributes, which can be removed individually
using
haven's zap_* functions.
zap_everything combines the majority of these into a single wrapper
function.
zap_everything(df)
df |
A |
zap_everything combines the following haven::zap_*
functions:
zap_label - to remove variable labels;
zap_labels - to remove value labels;
zap_formats - to remove format attributes;
zap_widths - to remove display width attributes;
zap_empty - to convert empty strings within
character columns into missing values.
x <- haven::read_sav(system.file("examples", "iris.sav", package = "haven"))
zap_everything(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.